@@ -1,5 +1,6 @@
 #!/bin/sh
 # vim: set noexpandtab:
+# This script generates the *.docs files for each individual dictionary.
 
 set -e
 
@@ -10,7 +11,7 @@ then
 fi
 
 ## variables
-FILES='COPYING AUTHORS README INSTALL ChangeLog'
+FILES='COPYING AUTHORS INSTALL ChangeLog README README.txt README.md'
 LANGLIST=`find . -maxdepth 1 -name '???-???' -printf "%f "`
 
 
